local Sorcerer = ...

-- Register common prefab nodes
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_0_RootPart", "SORCERER2_ROOT_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_0_Tiling0Part", "SORCERER2_TILING0_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_1_Tiling1Part", "SORCERER2_TILING1_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_2_Tiling2Part", "SORCERER2_TILING2_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_3_Tiling3Part", "SORCERER2_TILING3_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart", "SORCERER2_TOP_PREFAB")

-- Create default building part registering function 
function registerDefaultBuildingPart(_nodePrefix)
	Sorcerer:register({
		DataType = "BUILDING_PART",
		Id = _nodePrefix .. "_PART",
		Mover = { DataType = "BUILDING_PART_MOVER" },
		ConstructorData = {
                     DataType = "BUILDING_CONSTRUCTOR_DEFAULT",
                     CoreObjectPrefab = _nodePrefix .. "_PREFAB"
                }
	})
end

local defaultNodePrefixList = {
	"SORCERER2_TOP",
	"SORCERER2_TILING0",
	"SORCERER2_TILING1",
	"SORCERER2_TILING2",
	"SORCERER2_TILING3"
}

-- Register simple building part assets
for i, nodePrefix in ipairs(defaultNodePrefixList) do
	registerDefaultBuildingPart(nodePrefix)
end


-- Register the sorcerer house part
Sorcerer:register({
	DataType = "BUILDING_PART",
	Id = "SORCERER2_ROOT_PART",
	Name = "SORCERER2_ROOT_NAME",
	Description = "SORCERER2_ROOT_DESC",
	Category = "CORE",
	Mover = { DataType = "BUILDING_PART_MOVER_INSTANCE" },
	ConstructorData = {
		DataType = "BUILDING_CONSTRUCTOR_SCALER", -- Since there are different types of building constructor, 'DataType' is necessary here
		CoreObjectPrefab = "SORCERER2_ROOT_PREFAB",
		EndPart = "SORCERER2_TOP_PART",
		FillerList = {
			"SORCERER2_TILING3_PART",
			"SORCERER2_TILING2_PART",
			"SORCERER2_TILING1_PART"
                },
		BasementFillerList = {
			"SORCERER2_TILING0_PART",
			"SORCERER2_TILING0_PART",
			"SORCERER2_TILING0_PART"
         	},
		MinimumScale = 0,
		BasementScale = 1,
		IsVertical = true
	},
	Cost = {
		UpkeepCost = {
			{ Resource = "GOLD", Quantity = 0 }
		},
		RessourcesNeeded = { -- List of RESOURCE_QUANTITY_PAIR
			{ Resource = "WOOD", Quantity = 5 }
		}
	},
	BuildingFunction = {
		DataType = "BUILDING_FUNCTION_WORKPLACE",
		WorkerCapacity = 1,
                RelatedJob = { Job = "SORCERER", Behavior = "WORK_BEHAVIOR" }
	}
})

-- Register particule systems attachments

Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/SmokeEmitter", "SORCERER2_SMOKE_EMITTER_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitter", "SORCERER2_BAT_EMITTER_PREFAB")
Sorcerer:registerAssetId("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitterBack", "SORCERER2_BAT_EMITTER_BACK_PREFAB")


Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart", {
	DataType = "COMP_BUILDING_PART",
	FeedbackComponentListToActivate = {
                 { "SORCERER2_SMOKE_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" },
                 { "SORCERER2_BAT_EMITTER_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" },
                 { "SORCERER2_BAT_EMITTER_BACK_PREFAB", "COMP_PARTICLE_EMITTER_TOGGLE" }
	}
})

-- Register air vent particle system
Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "PARTICLE_SYSTEM_STONECUTTER_ROCK",
	IsPlaying = true,
	IsEmitting = false
})

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/SmokeEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

-- Register air vent particle system
Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitter", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "BAT2_PARTICLE_SYSTEM",
	IsPlaying = true,
	IsEmitting = false
})

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitter", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

-- Register air vent particle system
Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitterBack", {
	DataType = "COMP_PARTICLE_EMITTER",
	ParticleSystem = "BAT2_PARTICLE_SYSTEM_BACK",
	IsPlaying = true,
	IsEmitting = false
})

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_9_TopPart/BatEmitterBack", {
	DataType = "COMP_PARTICLE_EMITTER_TOGGLE",
	Enabled = false
})

-- Override building part components properties (generated by the building asset processor) to add building zones

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_0_RootPart", {
	DataType = "COMP_BUILDING_PART",
	HasBuildingZone = true,
	BuildingZone = { 4, 4 }
})

-- Register grounding components

Sorcerer:registerPrefabComponent("models/sorcerer2.fbx/Prefab/sorcerer/step_0_Tiling0Part/porte", {
	DataType = "COMP_GROUNDED"
})


